# Overview of the scvi-tools codebase

Below is a static view of the scvi-tools codebase shown at the abstraction of discrete layers of components. Only select
components are shown for each layer and only a single model is presented (scVI).

:::{figure} figures/codebase_overview.svg
:align: center
:alt: Codebase overview figure
:class: img-fluid
:::
